@@ -3,7 +3,7 @@ package Markdent::Regexes;
 use strict;
 use warnings;
 
-our $VERSION = '0.33';
+our $VERSION = '0.39';
 
 use List::AllUtils qw( uniq );
 
@@ -11,12 +11,13 @@ use base 'Exporter';
 
 our %EXPORT_TAGS = (
     block => [
-        qw( $HorizontalWS
+        qw(
+            $HorizontalWS
             $EmptyLine
             $EmptyLines
             $BlockStart
             $BlockEnd
-            ),
+        ),
     ],
     span  => [],
     other => [qw( $HTMLComment )],
